<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Blog;
use ImageKit\ImageKit; 
use Illuminate\Support\Str; 

class BlogController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $blogs = Blog::latest()->get();
        return view('admin.blog.index', compact('blogs'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.blog.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $count = Blog::count();
        $add = sprintf('%04d',$count) + 1;
        $code = sprintf('%04d',$add);
        $slugcheck = Blog::where('slug', Str::slug($request->title))->first();

        $blog = new Blog();
        $blog->name = $request->name;
        if ($slugcheck) {
            $blog->slug = Str::slug($request->name.'-'.$code);
        } else {
            $blog->slug = Str::slug($request->name);
        }
        $blog->details = $request->details;
        $blog->meta_title = $request->meta_title;
        $blog->meta_desc = $request->meta_desc;

        $image = $request->image;
        
        if (!empty($image)) {
            $image_name = hexdec(uniqid()) . '.' . $image->getClientOriginalExtension();
            $image->move(public_path('media/blogs/'), $image_name);
            $final = public_path('media/blogs/'.$image_name);

            $imageKit = new ImageKit(
                "public_P9rkzw8hGFmQWl6LH7nf0pewRss=",
                "private_OTRMf0JE8uv4ttiNpbiciTgZkcc=",
                "https://ik.imagekit.io/adsate"
            );
            $uploadFile = $imageKit->upload(array(
                "file" => fopen($final, "r"),
                "fileName" => "adsate.webp",
                "folder" => 'blogs',
                'transformation' => array(
                    [
                        'format' => 'webp',
                        'progressive' => true,
                        'quality' => '100',
                    ],
                )
            ));

            $blog->image = $uploadFile->result->name;
        } else {
            $blog->image = 'https://ik.imagekit.io/adsate/blog.webp';
        }

        $blog->save();

        $notification=array(
            'message'=>'Blog Added Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.blog')->with($notification); 
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $blog = Blog::findOrFail($id);
        return view('admin.blog.edit', compact('blog'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $oldblog = Blog::findOrFail($id);
        $code = $oldblog->code;
        $slugcheck = Blog::where('slug', Str::slug($request->name))->first();

        $blog = Blog::findOrFail($id);
        $blog->name = $request->name;
        if ($slugcheck) {
            $blog->slug = Str::slug($request->name.'-'.$code);
        } else {
            $blog->slug = Str::slug($request->name);
        }
        $blog->details = $request->details;
        $blog->meta_title = $request->meta_title;
        $blog->meta_desc = $request->meta_desc;

        $image = $request->image;
        
        if (!empty($image)) {
            $image_name = hexdec(uniqid()) . '.' . $image->getClientOriginalExtension();
            $image->move(public_path('media/blogs/'), $image_name);
            $final = public_path('media/blogs/'.$image_name);

            $imageKit = new ImageKit(
                "public_P9rkzw8hGFmQWl6LH7nf0pewRss=",
                "private_OTRMf0JE8uv4ttiNpbiciTgZkcc=",
                "https://ik.imagekit.io/adsate"
            );
            $uploadFile = $imageKit->upload(array(
                "file" => fopen($final, "r"),
                "fileName" => "adsate.webp",
                "folder" => 'blogs',
                'transformation' => array(
                    [
                        'format' => 'webp',
                        'progressive' => true,
                        'quality' => '100',
                    ],
                )
            ));

            $blog->image = $uploadFile->result->name;
        } else {
            $blog->image = $oldblog->image;
        }
        
        $blog->save();

        $notification=array(
            'message'=>'Blog Updated Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.blog')->with($notification); 
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $blog = Blog::findOrFail($id);
        $blog->delete();

        $notification=array(
            'message'=>'Blog deleted Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.blog')->with($notification);
    }
}
