<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Str;
use App\Models\Service;
use App\Models\ServiceItem;


class ServiceItemsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $serviceItems = ServiceItem::latest()->get();
        return view('admin.services.items.index', compact('serviceItems'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $services = Service::get();
        return view('admin.services.items.create', compact('services'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $features = json_encode($request->feature);

        $service = new ServiceItem();
        $service->name = $request->name;
        $service->service_id = $request->service_id;
        $service->slug = Str::slug($request->name);
        $service->short_desc = $request->short_desc;
        $service->meta_title = $request->meta_title;
        $service->meta_desc = $request->meta_desc;
        $service->price = $request->price;
        $service->services = $features;

        $service->save();

        $notification=array(
            'message'=>'Service Item Added Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.service.items')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $services = Service::get();
        $serviceItem = ServiceItem::findOrFail($id);
        return view('admin.services.items.edit', compact('services', 'serviceItem'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        

        $features = json_encode($request->feature);

        $service = ServiceItem::findOrFail($id);
        $service->name = $request->name;
        $service->service_id = $request->service_id;
        $service->slug = Str::slug($request->name);
        $service->short_desc = $request->short_desc;
        $service->meta_title = $request->meta_title;
        $service->meta_desc = $request->meta_desc;
        $service->price = $request->price;

        $service->services = $features;

        $service->save();

        $notification=array(
            'message'=>'Service Item Updated Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.service.items')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $service = ServiceItem::findOrFail($id);
        $service->delete();

        $notification=array(
            'message'=>'Service Item deleted Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.service.items')->with($notification);
    }
}
