<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Str;
use App\Models\Service;
use App\Models\ServiceItem;
use ImageKit\ImageKit; 

class ServicesController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $services = Service::latest()->get();
        return view('admin.services.index', compact('services'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.services.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'image' => 'required',
            'short_desc' => 'required',
            'meta_title' => 'required',
            'meta_desc' => 'required',
            'image' => 'required',
        ]);


        $service = new Service();
        $service->name = $request->name;
        $service->slug = Str::slug($request->name);
        $service->short_desc = $request->short_desc;
        $service->meta_title = $request->meta_title;
        $service->meta_desc = $request->meta_desc;

        $image = $request->image;

        if (!empty($image)) {
            $image_name = hexdec(uniqid()) . '.' . $image->getClientOriginalExtension();
            $image->move(public_path('media/services/images/'), $image_name);
            $final = public_path('media/services/images/'.$image_name);

            $imageKit = new ImageKit(
                "public_P9rkzw8hGFmQWl6LH7nf0pewRss=",
                "private_OTRMf0JE8uv4ttiNpbiciTgZkcc=",
                "https://ik.imagekit.io/adsate"
            );
            $uploadFile = $imageKit->upload(array(
                "file" => fopen($final, "r"),
                "fileName" => "adsate.webp",
                "folder" => 'services',
                'transformation' => array(
                    [
                        'format' => 'webp',
                        'progressive' => true,
                        'quality' => '100',
                    ],
                )
            ));

            $service->image = $uploadFile->result->name;

        } else {

            $service->image = 'https://ik.imagekit.io/adsate/service.webp';
        }

        $service->save();

        $notification=array(
            'message'=>'Service Added Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.services')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $service = Service::findOrFail($id);
        return view('admin.services.edit', compact('service'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'name' => 'required',
            'short_desc' => 'required',
            'meta_title' => 'required',
            'meta_desc' => 'required',
        ]);


        $service = Service::findOrFail($id);
        $service->name = $request->name;
        $service->slug = Str::slug($request->name);
        $service->short_desc = $request->short_desc;
        $service->meta_title = $request->meta_title;
        $service->meta_desc = $request->meta_desc;

        $image = $request->image;

        if (!empty($image)) {
            $image_name = hexdec(uniqid()) . '.' . $image->getClientOriginalExtension();
            $image->move(public_path('media/services/images/'), $image_name);
            $final = public_path('media/services/images/'.$image_name);

            $imageKit = new ImageKit(
                "public_P9rkzw8hGFmQWl6LH7nf0pewRss=",
                "private_OTRMf0JE8uv4ttiNpbiciTgZkcc=",
                "https://ik.imagekit.io/adsate"
            );
            $uploadFile = $imageKit->upload(array(
                "file" => fopen($final, "r"),
                "fileName" => "adsate.webp",
                "folder" => 'services',
                'transformation' => array(
                    [
                        'format' => 'webp',
                        'progressive' => true,
                        'quality' => '100',
                    ],
                )
            ));

            $service->image = $uploadFile->result->name;

        } else {

            $service->image = $service->image;
        }

        $service->save();

        $notification=array(
            'message'=>'Service Updated Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.services')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $service = Service::findOrFail($id);
        $service->delete();

        $notification=array(
            'message'=>'Service deleted Successfully.',
            'alert-type'=>'success'
        );

        return redirect()->route('admin.services')->with($notification);
    }
}
