<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Platform;
use App\Models\PurchaseType;
use App\Models\Pricing;
use Str;

class SocialController extends Controller
{
    function platforms() {
        $platforms = Platform::orderBy('id', 'asc')->get();

        return view('admin.social.platforms', compact('platforms'));
    }

    function purchaseTypes() {
        $platforms = Platform::get();
        $purchaseTypes = PurchaseType::orderBy('id', 'asc')->get();
        return view('admin.social.purchaseTypes', compact('purchaseTypes', 'platforms'));
    }


    function storePurchaseType(Request $request) {

        $request->validate([
            'purchaseTypeName' => 'required|string',
            'purchaseTypePlatform' => 'required',
        ]);

        $purchaseType = new PurchaseType();
        $purchaseType->platform_id = $request->input('purchaseTypePlatform');
        $purchaseType->name = $request->input('purchaseTypeName');
        $purchaseType->slug = Str::slug($request->input('purchaseTypeName'));
        $purchaseType->save();

        return response()->json(['message' => 'Purchase type saved successfully']);

    }

    function updatePurchaseType(Request $request) {

        $request->validate([
            'purchaseTypeName' => 'required|string',
            'purchaseTypePlatform' => 'required',
        ]);


        $purchaseType = PurchaseType::findOrFail($request->purchaseTypeEditInput);
        $purchaseType->platform_id = $request->input('purchaseTypePlatform');
        $purchaseType->name = $request->input('purchaseTypeName');
        $purchaseType->slug = Str::slug($request->input('purchaseTypeName'));
        $purchaseType->save();

        return response()->json(['message' => 'Purchase type updated successfully']);

    }

    function deletePurchaseType($id) {
        $purchaseType = PurchaseType::findOrFail($id);
        $purchaseType->pricings()->delete();
        $purchaseType->delete();
        $notification=array(
            'message'=>'Purchase Type deleted Successfully.',
            'alert-type'=>'success'
        );
        return redirect()->back()->with($notification);
    }

    function editPurchaseType(Request $reqeust) {
        $purchaseType = PurchaseType::findOrFail($reqeust->id);
        $platforms = Platform::orderBy('id', 'asc')->get();
        return response()->json([
            'purchaseType' => $purchaseType->id,
            'purchaseTypeName' => $purchaseType->name,
            'purchaseTypePlatform' => $purchaseType->platform->id,
            'platforms' => $platforms,
        ]);
    }

    function updatePurchaseTypePricing(Request $reqeust, $id) {
        $pricing = Pricing::findOrFail($id);
        $pricing->quantity = $reqeust->quantity;
        $pricing->price = $reqeust->price;
        $pricing->save();
        $notification=array(
            'message'=>'Pricing updated Successfully.',
            'alert-type'=>'success'
        );
        return redirect()->back()->with($notification);
    }

    function addPricing(Request $reqeust)  {

        $pricing = new Pricing();
        $pricing->quantity = $reqeust->quantity;
        $pricing->price = $reqeust->price;
        $pricing->platform_id = $reqeust->platformId;
        $pricing->purchase_type_id = $reqeust->purchaseTypeId;
        $pricing->save();

        $notification=array(
            'message'=>'Pricing added Successfully.',
            'alert-type'=>'success'
        );
        return redirect()->back()->with($notification);
    }

    function deletePricing($id) {
        $pricing = Pricing::findOrFail($id);
        $pricing->delete();
        $notification=array(
            'message'=>'Pricing deleted Successfully.',
            'alert-type'=>'success'
        );
        return redirect()->back()->with($notification);
    }
}
