<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\GuestController;
use App\Http\Controllers\ServicesController;
use App\Http\Controllers\ServiceItemsController;
use App\Http\Controllers\SocialController;
use App\Http\Controllers\BlogController;
use App\Http\Controllers\TestimonialController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Auth::routes(['register' => false]);

Route::get('/', [GuestController::class, 'index'])->name('index');

Route::get('/about', [GuestController::class, 'about']);
Route::get('/contact', [GuestController::class, 'contact']);
Route::post('/contact', [GuestController::class, 'submitForm']);
Route::get('/terms-of-use', [GuestController::class, 'tou']);
Route::get('/privacy-policy', [GuestController::class, 'privacy']);
Route::get('/cookie-policy', [GuestController::class, 'cookie']);
Route::get('/services', [GuestController::class, 'services']);
Route::get('/service/{slug}', [GuestController::class, 'service']);
Route::get('/service/checkout/{serviceSlug}/{itemslug}', [GuestController::class, 'serviceCheckout']);
Route::post('/pay/service/{serviceSlug}/{itemslug}', [GuestController::class, 'servicePurchase']);
Route::get('/service/purchase/success', [GuestController::class, 'serviceCheckoutSuccess']);

Route::get('/blog', [GuestController::class, 'blog']);
Route::get('/article/{slug}', [GuestController::class, 'article']);

Route::group([ 'as'=>'admin.', 'prefix'=>'admin', 'middleware'=>['auth', 'verified', 'isAdmin']],
function(){
    Route::get('/dashboard', [HomeController::class, 'index'])->name('home');
    Route::get('/settings', [HomeController::class, 'settings'])->name('settings');
    
    // Services
    Route::get('/services', [ServicesController::class, 'index'])->name('services');
    Route::get('/services/create', [ServicesController::class, 'create'])->name('create.service');
    Route::post('/services/create', [ServicesController::class, 'store'])->name('store.service');
    Route::get('/services/edit/{id}', [ServicesController::class, 'edit']);
    Route::post('/services/update/{id}', [ServicesController::class, 'update']);
    Route::get('/services/destroy/{id}', [ServicesController::class, 'destroy']);

    // Service Items
    Route::get('/serviceitems', [ServiceItemsController::class, 'index'])->name('service.items');
    Route::get('/serviceitems/create', [ServiceItemsController::class, 'create'])->name('create.service.item');
    Route::post('/serviceitems/create', [ServiceItemsController::class, 'store'])->name('store.service.item');
    Route::get('/serviceitems/edit/{id}', [ServiceItemsController::class, 'edit']);
    Route::post('/serviceitems/update/{id}', [ServiceItemsController::class, 'update']);
    Route::get('/serviceitems/destroy/{id}', [ServiceItemsController::class, 'destroy']);

    // Service Items
    Route::get('/blog', [BlogController::class, 'index'])->name('blog');
    Route::get('/blog/create', [BlogController::class, 'create'])->name('create.blog');
    Route::post('/blog/create', [BlogController::class, 'store'])->name('store.blog');
    Route::get('/blog/edit/{id}', [BlogController::class, 'edit']);
    Route::post('/blog/update/{id}', [BlogController::class, 'update']);
    Route::get('/blog/destroy/{id}', [BlogController::class, 'destroy']);

    // Service Items
    Route::get('/testimonial', [TestimonialController::class, 'index'])->name('testimonial');
    Route::get('/testimonial/create', [TestimonialController::class, 'create'])->name('create.testimonial');
    Route::post('/testimonial/create', [TestimonialController::class, 'store'])->name('store.testimonial');
    Route::get('/testimonial/edit/{id}', [TestimonialController::class, 'edit']);
    Route::post('/testimonial/update/{id}', [TestimonialController::class, 'update']);
    Route::get('/testimonial/destroy/{id}', [TestimonialController::class, 'destroy']);

    
    // Social
    Route::get('/social/utilities/platforms', [SocialController::class, 'platforms']);
    Route::get('/social/utilities/purchasetypes', [SocialController::class, 'purchaseTypes']);
    Route::post('store/purchaseType', [SocialController::class, 'storePurchaseType']);
    Route::get('delete/purchaseType/{id}', [SocialController::class, 'deletePurchaseType']);
    Route::get('edit/purchaseType', [SocialController::class, 'editPurchaseType']);
    Route::post('update/purchaseType', [SocialController::class, 'updatePurchaseType']);
    Route::post('update/platformtypes/pricing/{id}', [SocialController::class, 'updatePurchaseTypePricing']);
    Route::post('add/pricing', [SocialController::class, 'addPricing']);
    Route::get('delete/pricing/{id}', [SocialController::class, 'deletePricing']);

});
